@@ -20,7 +20,7 @@
   }
 
   # determine if this is a vega or vega_lite spec
-  library <- .schema_type(x[["$schema"]])$library
+  library <- parse_schema(x[["$schema"]])$library
 
   class_library <- paste0("vegaspec_", library)
 
