@@ -46,8 +46,6 @@ spec_mtcars_autosize$config <-
   )
 # ===
 
-has_node <- unname(nchar(Sys.which("node")) > 0L)
-
 test_that("autosize works", {
 
   expect_identical(
@@ -55,10 +53,6 @@ test_that("autosize works", {
     normalize(spec_mtcars_autosize)
   )
 
-  # Need to have node installed
-  skip_on_cran()
-  skip_if_not(has_node)
-
   vgspec_mtcars <- vw_to_vega(spec_mtcars)
 
   # autosize works on Vega (vs Vega-Lite)
